pygeodesy.booleans._Clip

Package pygeodesy :: Module booleans :: Class _Clip |
[frames] | no frames]

# Class _Clip

      object --+
               |
    named._Named --+
                   |
                  _Clip

(INTERNAL) A doubly-linked list representing a closed polygon of LatLonFHP or LatLonGH points, duplicates and intersections with other clips.

Instance Methods
__init__(self, composite, clipid=0) (INTERNAL) New `_Clip`. |
__contains__(self, point) Is the `point` in this clip? |
__eq__(self, other) Is this clip equivalent to an `other` clip, do both have the same `len`, the same points, in the same order, possibly rotated? |
__ge__(self, other) See method `__lt__`. |
__gt__(self, other) Is this clip `"above"` an `other` clip, located or stretched farther North or East? |
__hash__(self) hash(x) |
__iter__(self) Yield the points, duplicates and intersections. |
__le__(self, other) See method `__gt__`. |
__len__(self) Return the number of points, duplicates and intersections in this clip. |
__lt__(self, other) Is this clip `"below"` an `other` clip, located or stretched farther South or West? |
__ne__(self, other) See method `__eq__`. |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, composite, clipid=0) (Constructor) |
(INTERNAL) New `_Clip`. Overrides: object.__init__

### __hash__ (self) (Hashing function) |
hash(x) Overrides: object.__hash__ (inherited documentation)